@@ -7,7 +7,7 @@
  *  Original code:
  *  Copyright (C) 1999 Rainer Johanni <Rainer@Johanni.de> 
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -246,6 +246,9 @@ typedef struct
   
   alBITMAPINFOHEADER *bitmap_info_header;
   alWAVEFORMATEX *wave_format_ex[AVI_MAX_TRACKS];
+
+  void*		extradata;
+  unsigned long	extradata_size;
 } avi_t;
 
 #define AVI_MODE_WRITE  0
@@ -438,19 +441,21 @@ size_t AVI_read_wave_pcm_data( int fd, void * buffer, size_t buflen );
 size_t AVI_write_wave_pcm_data( int fd, const void * buffer, size_t buflen );
 
 
-struct AVIStreamHeader {
-  long  fccType;
-  long  fccHandler;
-  long  dwFlags;
-  long  dwPriority;
-  long  dwInitialFrames;
-  long  dwScale;
-  long  dwRate;
-  long  dwStart;
-  long  dwLength;
-  long  dwSuggestedBufferSize;
-  long  dwQuality;
-  long  dwSampleSize;
-};
+struct AVIStreamHeader
+{
+  uint32_t  fccType;
+  uint32_t  fccHandler;
+  uint32_t  dwFlags;
+  uint32_t  dwPriority;
+  uint32_t  dwInitialFrames;
+  uint32_t  dwScale;
+  uint32_t  dwRate;
+  uint32_t  dwStart;
+  uint32_t  dwLength;
+  uint32_t  dwSuggestedBufferSize;
+  uint32_t  dwQuality;
+  uint32_t  dwSampleSize;
+} __attribute__((__packed__));
+
 
 #endif
