@@ -31,7 +31,9 @@
 #include <inttypes.h>
 #include <assert.h>
 
-#include <ffmpeg/avcodec.h>
+#include "transcode.h"
+
+#include <libavcodec/avcodec.h>
 
 #include "aud_aux.h"
 #include "ac3.h"
@@ -131,8 +133,8 @@ static int audio_pass_through_ac3(char *aud_buffer, int aud_size, avi_t *avifile
 static int audio_pass_through_pcm(char *aud_buffer, int aud_size, avi_t *avifile);
 static int audio_mute(char *aud_buffer, int aud_size, avi_t *avifile);
 int audio_encode(char *aud_buffer, int aud_size, avi_t *avifile);
-int audio_close();
-int audio_stop();
+int audio_close(void);
+int audio_stop(void);
 static char * lame_error2str(int error);
 #ifdef HAVE_LAME
 static void no_debug(const char *format, va_list ap) {return;}
@@ -361,8 +363,7 @@ static int audio_init_ffmpeg(vob_t *vob, int o_codec)
 
     pthread_mutex_lock(&init_avcodec_lock);
     avcodec_init();
-    register_avcodec(&ac3_encoder);
-    register_avcodec(&mp2_encoder);
+    avcodec_register_all();
     pthread_mutex_unlock(&init_avcodec_lock);
 
     switch (o_codec) {
@@ -1048,7 +1049,7 @@ int audio_encode(char *aud_buffer, int aud_size, avi_t *avifile)
 /**
  * Close audio stream
  */
-int audio_close()
+int audio_close(void)
 {    
 	/* reset bitrate flag for AC3 pass-through */
 	bitrate = 0;
@@ -1084,7 +1085,7 @@ int audio_close()
 
 
 
-int audio_stop()
+int audio_stop(void)
 {    
         if (input) free(input); input = NULL;
         if (output) free(output); output = NULL;
