@@ -24,6 +24,7 @@
 
 #include <stdio.h>
 #include <unistd.h>
+#include <errno.h>
 
 #include "transcode.h"
 #include "probe_export.h"
@@ -32,7 +33,6 @@
 #define MOD_VERSION "v0.1 (2003-02-26)"
 #define MOD_CODEC   "(video) null | (audio) ac3"
 
-extern int errno;
 
 static int   verbose_flag=TC_QUIET;
 static int   capability_flag=TC_CAP_PCM;
