@@ -48,6 +48,7 @@
 */
 
 #include <stdio.h>
+#include <errno.h>
 #include <unistd.h>
 
 #include "transcode.h"
@@ -63,7 +64,6 @@ static int   capability_flag=TC_CAP_PCM;
 #define MOD_PRE mp2
 #include "export_def.h"
 
-extern int errno;
 
 static FILE *pFile = NULL;
 static double speed = 0.0;
@@ -141,7 +141,7 @@ MOD_open
                            vob->mp3bitrate,
                            srate,
                            out_fname,
-                           vob->verbose > 1 ? "" : " >&/dev/null");
+                           vob->verbose > 1 ? "" : " >/dev/null 2>&1");
 
     if (tc_test_string(__FILE__, __LINE__, PATH_MAX - strlen(buf), result, errno))
         return(TC_EXPORT_ERROR);
