@@ -6,7 +6,7 @@
  *
  *  based on export mp2enc.c
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ MOD_open
     ifreq = vob->a_rate;
     orate = vob->mp3bitrate;
     ochan = vob->dm_chan;
-    chan = (ochan==2) ? 'j':'m';
+    chan = (ochan==2) ? (vob->mp3mode==1 ? 's' : 'j') : 'm';
 
     /* default out freq */
     if(ofreq==0)
@@ -108,7 +108,7 @@ MOD_open
       if (tc_test_program("sox") != 0) return (TC_EXPORT_ERROR);
             
       /* add sox for conversion */
-      sprintf(buf,"sox %s -r %d -c %d -t raw - -r %d -t raw - polyphase "
+      snprintf(buf, sizeof(buf), "sox %s -r %d -c %d -t raw - -r %d -t raw - polyphase "
 	      "2>/dev/null | ",
 	      (vob->dm_bits==16)?"-w -s":"-b -u", 
 	      ifreq, ochan, ofreq);
@@ -122,7 +122,8 @@ MOD_open
     */
 	    
     /* toolame command line */
-    sprintf(ptr, "toolame -s %0.3f -b %d -m %c - \"%s.mp2\" 2>/dev/null %s", 
+    /* ptr is a pointer to buf */
+    snprintf(ptr, sizeof(buf), "toolame -s %0.3f -b %d -m %c - \"%s.mp2\" 2>/dev/null %s", 
 	    (double)ofreq/1000.0, orate, chan, vob->audio_out_file, (vob->ex_a_string?vob->ex_a_string:""));
 	
     fprintf (stderr,"[%s] cmd=%s\n", MOD_NAME, buf);
