@@ -4,7 +4,7 @@
  *  Copyright (C) Tilmann Bitterberg - June 2002
  *    Based on Code from mplayers cropdetect by A'rpi
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,27 +27,11 @@
 #define MOD_CAP     "detect clipping parameters (-j or -Y)"
 #define MOD_AUTHOR  "Tilmann Bitterberg, A'rpi"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-#include <unistd.h>
-#include <inttypes.h>
-
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
 
+
 // basic parameter
 
 typedef struct MyFilterData {
@@ -139,7 +123,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
   //
   //----------------------------------
 
-
   if(ptr->tag & TC_FILTER_INIT) {
 
     if((vob = tc_get_vob())==NULL) return(-1);
@@ -203,12 +186,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	return -1;
     }
 
-
-
-
     // filter init ok.
     if (verbose) printf("[%s] %s %s #%d\n", MOD_NAME, MOD_VERSION, MOD_CAP, ptr->filter_id);
-
     
     return(0);
   }
@@ -219,7 +198,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
   //
   //----------------------------------
 
-  
   if(ptr->tag & TC_FILTER_CLOSE) {
 
     if (mfd[ptr->filter_id]) { 
@@ -236,7 +214,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // filter frame routine
   //
   //----------------------------------
-
     
   // tag variable indicates, if we are called before
   // transcodes internal video/audo frame processing routines
@@ -283,7 +260,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	}
     }
 
-
     t = (mfd[ptr->filter_id]->y1+1)&(~1);
     l = (mfd[ptr->filter_id]->x1+1)&(~1);
     b = ptr->v_height - ((mfd[ptr->filter_id]->y2+1)&(~1));
