@@ -31,7 +31,7 @@
 #ifdef EMULATE_FAST_INT
 #undef EMULATE_FAST_INT
 #endif
-#include <ffmpeg/avcodec.h>
+#include <libavcodec/avcodec.h>
 #include "yuv2rgb.h"
 
 #define READ_BUFFER_SIZE (10*1024*1024)
@@ -192,7 +192,11 @@ void decode_lavc(decode_t *decode)
   lavc_dec_context->width  = x_dim;
   lavc_dec_context->height = y_dim;
 
+#if LIBAVCODEC_VERSION_INT < ((52<<16)+(0<<8)+0)
   lavc_dec_context->error_resilience = 2;
+#else
+  lavc_dec_context->error_recognition = 2;
+#endif
   lavc_dec_context->error_concealment = 3;
   lavc_dec_context->workaround_bugs = FF_BUG_AUTODETECT;
 
