@@ -32,6 +32,8 @@
 #define MOD_VERSION "v0.0.2 (2004-05-11)"
 #define MOD_CODEC   "(video) rendered by ffmpeg binary | (audio) rendered by ffmpeg binary"
 
+#include <errno.h>
+
 #include "transcode.h"
 
 static int verbose_flag = TC_QUIET;
@@ -41,8 +43,7 @@ static int capability_flag = TC_CAP_YUV | TC_CAP_RGB | TC_CAP_VID | TC_CAP_PCM;
 #include "import_def.h"
 
 
-extern int errno;
-char import_cmd_buf[TC_BUF_MAX];
+static char import_cmd_buf[TC_BUF_MAX];
 
 static char audiopipe[40] = "/tmp/ffbin2transcode-audio.XXXXXX";
 static char videopipe[40] = "/tmp/ffbin2transcode-audio.XXXXXX";
