@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,26 +21,23 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
-#include "transcode.h"
-#include "ac3scan.h"
-#include "demuxer.h"
-#include "clone.h"
-
 #define MOD_NAME    "import_vob.so"
 #define MOD_VERSION "v0.6.0 (2003-10-02)"
 #define MOD_CODEC   "(video) MPEG-2 | (audio) MPEG/AC3/PCM | (subtitle)"
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_VID|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_PCM|TC_CAP_AC3;
+#include "transcode.h"
 
+static int verbose_flag = TC_QUIET;
+static int capability_flag = TC_CAP_VID | TC_CAP_RGB | TC_CAP_YUV | TC_CAP_PCM | TC_CAP_AC3;
 
 #define MOD_PRE vob
 #include "import_def.h"
 
+#include "ac3scan.h"
+#include "demuxer.h"
+#include "clone.h"
+
+
 #define MAX_BUF 1024
 char import_cmd_buf[MAX_BUF];
 
@@ -77,11 +74,11 @@ MOD_open
 
   int off=0x80;
   
-  (vob->ps_seq1 != 0 || vob->ps_seq2 != INT_MAX) ? snprintf(seq_buf, 256, "-S %d,%d-%d", vob->ps_unit, vob->ps_seq1, vob->ps_seq2) : sprintf(seq_buf, "-S %d", vob->ps_unit);
+  (vob->ps_seq1 != 0 || vob->ps_seq2 != INT_MAX) ? snprintf(seq_buf, sizeof(seq_buf), "-S %d,%d-%d", vob->ps_unit, vob->ps_seq1, vob->ps_seq2) : snprintf(seq_buf, sizeof(seq_buf), "-S %d", vob->ps_unit);
   
   if(param->flag == TC_AUDIO) {
 
-    sprintf(dem_buf, "-M %d", vob->demuxer);
+    snprintf(dem_buf, sizeof(dem_buf), "-M %d", vob->demuxer);
 
     codec = vob->im_a_codec;
     syncf = vob->sync;
@@ -177,7 +174,7 @@ MOD_open
   
   if(param->flag == TC_SUBEX) {  
     
-    sprintf(dem_buf, "-M %d", vob->demuxer);
+    snprintf(dem_buf, sizeof(dem_buf), "-M %d", vob->demuxer);
     
     codec = vob->im_a_codec;
     syncf = vob->sync;
@@ -211,9 +208,9 @@ MOD_open
 	  printf("[%s] failed to create a temporary pipe\n", MOD_NAME);
 	  return(TC_IMPORT_ERROR);
 	} 
-	sprintf(dem_buf, "-M %d -f %f -P %s %s %s", vob->demuxer, vob->fps, logfile, ((vob->vob_chunk==0)? "": "-O"),
+	snprintf(dem_buf, sizeof(dem_buf), "-M %d -f %f -P %s %s %s", vob->demuxer, vob->fps, logfile, ((vob->vob_chunk==0)? "": "-O"),
 		((vob->hard_fps_flag==1)?"-H":""));
-      } else sprintf(dem_buf, "-M %d", vob->demuxer);
+      } else snprintf(dem_buf, sizeof(dem_buf), "-M %d", vob->demuxer);
       
       //determine subtream id for sync adjustment
       //default is off=0x80
