@@ -1,9 +1,9 @@
 /*
  *	import_v4l2.c
  *
- *	By Erik Slagter Sept 2003
+ *	By Erik Slagter <erik@slagter.name> Sept 2003
  * 
- *	This file is part of transcode, a linux video stream processing tool
+ *	This file is part of transcode, a video stream processing tool
  *
  *	transcode is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -21,21 +21,23 @@
  *
  */
 
+#define MOD_NAME		"import_v4l2.so"
+#define MOD_VERSION		"v1.3.5 (2005-03-11)"
+#define MOD_CODEC		"(video) v4l2 | (audio) pcm"
+
+#include "transcode.h"
+
+static int verbose_flag		= TC_QUIET;
+static int capability_flag	= TC_CAP_RGB | TC_CAP_YUV | TC_CAP_YUV422 | TC_CAP_PCM;
+
+#define MOD_PRE			v4l2
+#include "import_def.h"
+
 #define _ISOC9X_SOURCE 1
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <pthread.h>
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 #include <sys/soundcard.h>
 #include <sys/ioctl.h>
 #include <sys/mman.h>
-#include <sys/time.h>
 
 #include <linux/types.h>
 
@@ -49,18 +51,8 @@
 #include "videodev2.h"
 #endif
 
-#include "transcode.h"
 #include "filter/mmx.h"
 
-#define MOD_NAME		"import_v4l2.so"
-#define MOD_VERSION		"v1.3.4 (2004-08-25)"
-#define MOD_CODEC		"(video) v4l2 | (audio) pcm"
-
-static int verbose_flag		= TC_QUIET;
-static int capability_flag	= TC_CAP_RGB | TC_CAP_YUV | TC_CAP_YUV422 | TC_CAP_PCM;
-
-#define MOD_PRE			v4l2
-#include "import_def.h"
 
 /*
 	use se ts=4 for correct layout
@@ -104,6 +96,8 @@ static int capability_flag	= TC_CAP_RGB | TC_CAP_YUV | TC_CAP_YUV422 | TC_CAP_PC
 			EMS added experimental code to make sa7134 survive sync glitches
 	1.3.3	EMS adapted fast memcpy to new default transcode method
 	1.3.4	EMS fixed RGB24 capturing bug when using saa7134.
+	1.3.5	EMS test with unrestricted cloning/dropping of frames using resync_interval=0
+	            adjusted saa7134 audio message to make clear the user must take action
 
 	TODO
 
@@ -148,7 +142,7 @@ static v4l2_fmt_t		v4l2_fmt;
 static v4l2_resync_op	v4l2_video_resync_op = resync_none;
 
 static int	v4l2_saa7134_audio = 0;
-static int	v4l2_overrun_guard = 1;
+static int	v4l2_overrun_guard = 0;
 static int 	v4l2_resync_margin_frames = 0;
 static int 	v4l2_resync_interval_frames = 0;
 static int 	v4l2_buffers_count;
@@ -657,7 +651,7 @@ int v4l2_video_init(int layout, const char * device, int width, int height, int
 
 	if(verbose_flag & TC_INFO)
 	{
-		if(v4l2_resync_margin_frames == 0 || v4l2_resync_interval_frames == 0)
+		if(v4l2_resync_margin_frames == 0)
 			fprintf(stderr, module "%s", "resync disabled\n");
 		else
 			fprintf(stderr, module "resync enabled, margin = %d frames, interval = %d frames, \n",
@@ -1076,9 +1070,10 @@ int	v4l2_video_get_frame(size_t size, char * data)
 
 	v4l2_video_resync_op = resync_none;
 
-	if(((v4l2_resync_margin_frames != 0) && (v4l2_resync_interval_frames != 0)) &&
-			((v4l2_video_sequence % v4l2_resync_interval_frames) == 0) &&
-			(v4l2_video_sequence != 0) && (v4l2_audio_sequence != 0))
+	if(		(v4l2_resync_margin_frames != 0)	&&
+			(v4l2_video_sequence != 0)			&&
+			(v4l2_audio_sequence != 0)			&&
+			((v4l2_resync_interval_frames == 0) || (v4l2_video_sequence % v4l2_resync_interval_frames) == 0)	)
 	{
 		if(abs(v4l2_audio_sequence - v4l2_video_sequence) > v4l2_resync_margin_frames)
 		{
@@ -1140,7 +1135,7 @@ int v4l2_video_grab_stop(void)
 
 int v4l2_audio_init(const char * device, int rate, int bits, int channels)
 {
-	int tmp;
+	int version, tmp;
 
 	if((v4l2_audio_fd = open(device, O_RDONLY, 0)) < 0)
 	{
@@ -1157,6 +1152,12 @@ int v4l2_audio_init(const char * device, int rate, int bits, int channels)
 		return(1);
 	}
 
+	if(ioctl(v4l2_audio_fd, OSS_GETVERSION, &version) < 0)
+	{
+		perror(module "OSS_GETVERSION");
+		return(1);
+	}
+	
 	tmp = bits == 8 ? AFMT_U8 : AFMT_S16_LE;
 
 	if(ioctl(v4l2_audio_fd, SNDCTL_DSP_SETFMT, &tmp) < 0)
@@ -1176,30 +1177,33 @@ int v4l2_audio_init(const char * device, int rate, int bits, int channels)
 
 	tmp = 0;
 
-	if(ioctl(v4l2_audio_fd, SOUND_PCM_WRITE_RATE, &tmp) < 0)
-		(void)0;
-	else
+	if (version < 0x040000)
 	{
-		if(ioctl(v4l2_audio_fd, SOUND_PCM_READ_RATE, &tmp) < 0)
+		if(ioctl(v4l2_audio_fd, SNDCTL_DSP_SPEED, &tmp) < 0)
+			(void)0;
+		else
 		{
-			perror(module "SOUND_PCM_READ_RATE");
-			return(1);
-		}
+			if(ioctl(v4l2_audio_fd, SOUND_PCM_READ_RATE, &tmp) < 0)
+			{
+				perror(module "SOUND_PCM_READ_RATE");
+				return(1);
+			}
 
-		if(tmp == 32000)
-			v4l2_saa7134_audio = 1;
+			if(tmp == 32000)
+				v4l2_saa7134_audio = 1;
+		}
 	}
 
 	if(v4l2_saa7134_audio)
 	{
 		if(verbose_flag & TC_INFO)
-			fprintf(stderr, module "Audio input from saa7134 detected, audio sample rate fixed at 32 Khz\n");
+			fprintf(stderr, module "Audio input from saa7134 detected, you should set audio sample rate to 32 Khz using -e\n");
 	}
 	else
 	{
-		if(ioctl(v4l2_audio_fd, SOUND_PCM_WRITE_RATE, &rate) < 0)
+		if(ioctl(v4l2_audio_fd, SNDCTL_DSP_SPEED, &rate) < 0)
 		{
-			perror(module "SOUND_PCM_WRITE_RATE");
+			perror(module "SNDCTL_DSP_SPEED");
 			return(1);
 		}
 	}
