@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1060,13 +1060,12 @@ void yuv422_deinterlace_linear(char *image, int width, int height)
   
 #if 0
 #ifdef ARCH_X86 
-#ifdef HAVE_ASM_NASM
-  
   if(tc_accel & MM_MMX)  yuv422_average = ac_average_mmx;
   if(tc_accel & MM_SSE)  yuv422_average = ac_average_sse;
   if(tc_accel & MM_SSE2) yuv422_average = ac_average_sse2;
-  
 #endif
+#ifdef ARCH_X86_64
+  if(tc_accel & MM_SSE2) yuv422_average = ac_average_sse2;
 #endif
 #endif
 
@@ -1085,25 +1084,24 @@ void yuv422_deinterlace_linear_blend(char *image, char *tmp, int width, int heig
   
 #if 0
 #ifdef ARCH_X86 
-#ifdef HAVE_ASM_NASM
-
   if(tc_accel & MM_MMX) {
     yuv422_average = ac_average_mmx;  
 //    memcpy_accel = ac_memcpy_mmx;
   }
-
   if(tc_accel & MM_SSE) {
     yuv422_average = ac_average_sse;
 //    memcpy_accel = ac_memcpy_sse;
   }
-
   if(tc_accel & MM_SSE2) {
     yuv422_average = ac_average_sse2;
 //    memcpy_accel = ac_memcpy_sse2;
   }
-
-  
 #endif
+#ifdef ARCH_X86_64
+  if(tc_accel & MM_SSE2) {
+    yuv422_average = ac_average_sse2;
+//    memcpy_accel = ac_memcpy_sse2;
+  }
 #endif
 #endif // 0
   
