@@ -42,7 +42,9 @@
 
 void version()
 {
-  printf("%s (%s v%s) (C) 2003-2004 Tilmann Bitterberg\n", EXE, PACKAGE, VERSION);
+  printf("%s (%s v%s) (C) 2003-2004 Tilmann Bitterberg,"
+                        " 2004-2008 Transcode Team\n",
+                      EXE, PACKAGE, VERSION);
 }
 
 
