@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,7 +35,9 @@
 
 void version()
 {
-  printf("%s (%s v%s) (C) 2001-2004 Thomas Oestreich, T. Bitterberg\n", EXE, PACKAGE, VERSION);
+  printf("%s (%s v%s) (C) 2001-2004 Thomas Oestreich, T. Bitterberg,"
+                        " 2004-2008 Transcode Team\n",
+                      EXE, PACKAGE, VERSION);
 }
 
 void usage(int status)
